@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -446,6 +446,59 @@ $enabled = '1';
 						$enabled = '1';
 
 						print '<h2>' . __('Pre-installation Checks') .'</h2>';
+						print '<h3>' . __('Location checks') . '</h3>';
+
+						// Get request URI and break into parts
+						$test_request_uri = $_SERVER['REQUEST_URI']; 
+						$test_request_parts = parse_url($test_request_uri);
+						$test_request_path = $test_request_parts['path'];
+						$test_request_len = strlen($test_request_parts['path']);
+
+						// Get current script name (filename only)
+						$test_script_name = basename($_SERVER['SCRIPT_NAME']);
+						$test_script_len = strlen($test_script_name);
+
+						// Get end of the path of URI and see if it's our script
+						$test_script_part = substr($test_request_path, $test_request_len - $test_script_len);
+						$test_script_result = strcmp($test_script_part, $test_script_name);
+
+						// Assume desired path is the URI
+						$test_final_path = $test_request_parts['path'];
+
+						// Script was found in path, so remove it
+						if ($test_script_result === 0) {
+							$test_final_path = substr($test_final_path,0,strlen($test_final_path) - $test_script_len);
+						}
+
+						// Add the install subfolder to defined path location
+						// and check if it matches, if not there will likely be problems
+						$test_config_path = $config['url_path'] . 'install/';
+						$test_compare_result = strcmp($test_config_path,$test_final_path);
+
+						/*
+						 * Uncmment the following to debug the above change
+						 *
+						print '<p>Testing [' . $test_config_path . '] matches [' . $test_final_path .'] result = '.$test_compare_result.'('.gettype($test_compare_result).')</p>';
+
+						print '<p>request_uri = ' . strlen($test_request_uri) . ' [' . $test_request_uri . ']</p>';
+						print '<p>request_parts = ' . var_export($test_request_parts, true) . '</p>';
+						print '<p>request_path = ' . strlen($test_request_path) . ' [' . $test_request_path . ']</p>';
+
+						print '<p>script_name = ' . strlen($test_script_name) . ' [' . $test_script_name . ']</p>';
+							print '<p>script_part = ' . strlen($test_script_part) . ' [' . $test_script_part . ']</p>';
+						print '<p>script_result = ' . $test_script_result . '</p>';
+						print '<p>final_path = ' . strlen($test_final_path) . ' [' . $test_final_path . ']</p>';
+						 *
+						 * The above code should probably be removed once tested.
+						 */
+
+						// The path was not what we expected so print an error
+						if ($test_compare_result !== 0) {
+							print '<p class="textError"><strong>' . __('ERROR:') . '</strong> ' .  __('Please update config.php with the correct relative URI location of Cacti (url_path).') . '</p>';
+						} else {
+							print '<p>' . __('Your Cacti configuration has the relative correct path (url_path) in config.php.') . '</p>';
+						}
+
 						print '<h3>' . __('MySQL TimeZone Support') .'</h3>';
 						$mysql_timezone_access = db_fetch_assoc('SHOW COLUMNS FROM mysql.time_zone_name', false);
 						if (sizeof($mysql_timezone_access)) {
@@ -463,6 +516,15 @@ $enabled = '1';
 							print '<p>' . __('Your Cacti database account has access to the MySQL TimeZone database and that database is populated with global TimeZone information.') . '</p>';
 						}
 
+						print '<h3>' . __('PHP Timezone Support') .'</h3>';
+
+						if (ini_get('date.timezone') == '') {
+							print '<p class="textError"><strong>' . __('ERROR:') . '</strong> ' .  __('Your Web Servers PHP Timezone settings have not been set.  Please edit php.ini and uncomment the \'date.timezone\' setting and set it to the Web Servers Timezone per the PHP installation instructions prior to installing Cacti.') . '</p>';
+							$enabled = '0';
+						} else {
+							print '<p>' . __('Your Web Servers PHP is properly setup with a Timezone.') . '</p>';
+						}
+
 						print '<h3>' . __('Required PHP Module Support') .'</h3>';
 
 						print '<p>' .  __('Cacti requires several PHP Modules to be installed to work properly. If any of these are not installed, you will be unable to continue the installation until corrected. In addition, for optimal system performance Cacti should be run with certain MySQL system variables set.  Please follow the MySQL recommendations at your discretion.  Always seek the MySQL documentation if you have any questions.') . '</p>';
@@ -811,9 +873,9 @@ $enabled = '1';
 							print '<p><strong>' . __('Required Writable at Install Time Only') . '</strong></p>';
 							foreach($install_paths as $path) {
 								if (is_writable($path)) {
-									print '<p>'. $path . ' is <font color="#008000">' . __('Writable') . '</font></p>';
+									print __('<p>%s is <font color="#008000">Writable</font></p>', $path);
 								} else {
-									print '<p>'. $path . ' is <font color="#FF0000">' . __('Not Writable') . '</font></p>';
+									print __('<p>%s is <font color="#FF0000">Not Writable</font></p>', $path);
 									$writable = false;
 								}
 							}
@@ -821,9 +883,9 @@ $enabled = '1';
 							print '<p><strong>' . __('Required Writable after Install Complete') . '</strong></p>';
 							foreach($always_paths as $path) {
 								if (is_writable($path)) {
-									print '<p>'. $path . ' is <font color="#008000">' . __('Writable') . '</font></p>';
+									print __('<p>%s is <font color="#008000">Writable</font></p>', $path);
 								} else {
-									print '<p>'. $path . ' is <font color="#FF0000">' . __('Not Writable') . '</font></p>';
+									print __('<p>%s is <font color="#FF0000">Not Writable</font></p>', $path);
 									$writable = false;
 								}
 							}
@@ -831,9 +893,9 @@ $enabled = '1';
 							print '<p><strong>' . __('Required Writable after Install Complete') . '</strong></p>';
 							foreach($remote_paths as $path) {
 								if (is_writable($path)) {
-									print '<p>'. $path . ' is <font color="#008000">' . __('Writable') . '</font></p>';
+									print __('<p>%s is <font color="#008000">Writable</font></p>', $path);
 								} else {
-									print '<p>'. $path . ' is <font color="#FF0000">' . __('Not Writable') . '</font></p>';
+									print __('<p>%s is <font color="#FF0000">Not Writable</font></p>', $path);
 									$writable = false;
 								}
 							}
@@ -914,7 +976,7 @@ $enabled = '1';
 							$upgrade_results = '';
 							foreach ($_SESSION['cacti_db_install_cache'] as $cacti_upgrade_version => $actions) {
 								// output version header
-								$upgrade_results .= '<h4>Version: ' . $cacti_upgrade_version . '</h4>' . PHP_EOL;
+								$upgrade_results .= '<h4>' . __('Version: ') . $cacti_upgrade_version . '</h4>' . PHP_EOL;
 
 								// show results from version upgrade
 								foreach ($actions as $action) {
