@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -379,11 +379,15 @@ function get_filter_request_var($name, $filter = FILTER_VALIDATE_INT, $options =
 			} elseif (isempty_request_var($name)) {
 				$value = '';
 			} elseif ($filter == FILTER_VALIDATE_IS_REGEX) {
+				if (is_base64_encoded($_REQUEST[$name])) {
+					$_REQUEST[$name] = utf8_decode(base64_decode($_REQUEST[$name]));
+				}
+
 				$valid = validate_is_regex($_REQUEST[$name]);
 				if ($valid === true) {
 					$value = $_REQUEST[$name];
 				} else {
-					$value = FALSE;
+					$value = false;
 					$custom_error = $valid;
 				}
 			} elseif ($filter == FILTER_VALIDATE_IS_NUMERIC_ARRAY) {
@@ -428,7 +432,7 @@ function get_filter_request_var($name, $filter = FILTER_VALIDATE_INT, $options =
 
 		if ($value === false) {
 			if ($filter == FILTER_VALIDATE_IS_REGEX) {
-				$_SESSION['custom_error'] = __('The search term "%s" is not valid. Error is %s', get_nfilter_request_var($name), $cusom_error);
+				$_SESSION['custom_error'] = __('The search term "%s" is not valid. Error is %s', get_nfilter_request_var($name), $custom_error);
 				set_request_var($name, '');
 				raise_message('custom_error');
 			} else {
@@ -570,7 +574,7 @@ function validate_store_request_vars($filters, $sess_prefix = '') {
 					unset_request_var($variable);
 				} elseif (isset_request_var('reset')) {
 					kill_session_var($session_variable);
-				} elseif (isset($options['pageset'])) {
+				} elseif (isset($options['pageset']) && $options['pageset'] == true) {
 					$changed += check_changed($variable, $session_variable);
 				}
 			}
@@ -596,6 +600,10 @@ function validate_store_request_vars($filters, $sess_prefix = '') {
 				} elseif (isempty_request_var($variable)) {
 					$value = '';
 				} elseif ($options['filter'] == FILTER_VALIDATE_IS_REGEX) {
+					if (is_base64_encoded($_REQUEST[$variable])) {
+						$_REQUEST[$variable] = utf8_decode(base64_decode($_REQUEST[$variable]));
+					}
+
 					$valid = validate_is_regex($_REQUEST[$variable]);
 					if ($valid === true) {
 						$value = $_REQUEST[$variable];
@@ -670,6 +678,9 @@ function validate_store_request_vars($filters, $sess_prefix = '') {
 	if ($changed) {
 		set_request_var('page', 1);
 		set_request_var('changed', 1);
+		$_SESSION[$sess_prefix . '_page'] = 1;
+	} elseif (!isset_request_var('page') && isset($_SESSION[$sess_prefix . '_page'])) {
+		set_request_var('page', $_SESSION[$sess_prefix . '_page']);
 	}
 }
 
@@ -745,8 +756,8 @@ function get_order_string() {
 function remove_column_from_order_string($column) {
 	$page = get_order_string_page();
 
-	if (isset($_SESSIION['sort_data'][$page][$column])) {
-		unset($_SESSIION['sort_data'][$page][$column]);
+	if (isset($_SESSION['sort_data'][$page][$column])) {
+		unset($_SESSION['sort_data'][$page][$column]);
 		update_order_string(true);
 	}
 }
